/*
 * Classe permettant la lecture des fichiers de configuration (App.config) sur le Compact Framework
 * Auteur: LEBRUN Thomas < thomas.lebrun@supinfo.com >
 * */
using System;
using System.IO;
using System.Xml;
using System.Windows.Forms;

namespace ContactsPPC
{
	/// <summary>
	/// Classe permettant la lecture des fichiers de configuration (App.config) sur le Compact Framework
	/// </summary>
	public class ConfigReader
	{
		private static string CONFIG_FILE = @"\My Documents\ContactPPCOptions.config";

		private XmlTextReader LecteurXml = null;
		private FileStream StreamFichier = null;

		/// <summary>
		/// Mthode utilise pour charger le fichier de configuration dans un XmlTextReader
		/// </summary>
		/// <returns>Un XmlTextReader si tout va bien. Null dans le cs contraire.</returns>
		private XmlTextReader ReadConfig()
		{
			try
			{
				StreamFichier = new FileStream(CONFIG_FILE, FileMode.Open, FileAccess.ReadWrite, FileShare.ReadWrite);

				LecteurXml = new XmlTextReader(StreamFichier);
			}
			catch(IOException Ex)
			{
				MessageBox.Show("Erreur inattendue.\n" + Ex.Message, "Erreur", MessageBoxButtons.OK, MessageBoxIcon.Exclamation, MessageBoxDefaultButton.Button1);
			}

			return LecteurXml;
		}

		/// <summary>
		/// Rcupre, dans le fichier XML, la valeur de noeud demand.
		/// </summary>
		/// <param name="ElementName">Noeud dont on veut la valeur</param>
		/// <returns>Une chane de caractre reprsentant la valeur de noeud demnd.</returns>
		public string GetXmlValue(string ElementName)
		{
			string Value = null;
			XmlTextReader XmlReader = null; 	
				
			try 
			{
				// Lecture du fichier de configuation
				XmlReader = ReadConfig();
								
				// Tant que l'on peut lire
				while ( XmlReader.Read() )
				{
					// On rcupre le type de noeud actuel
					XmlNodeType NodeType = XmlReader.NodeType;		
					
					// Si c'est un lment
					if( NodeType == XmlNodeType.Element )
					{
						// et qu'il vaut "add" et que la valeur de "key" est gale ) celle passe en paramtre
						if (XmlReader.Name.Equals("add") && XmlReader.GetAttribute("key").Equals(ElementName))
						{
							// On rcupre la valeur de cet lment
							Value = XmlReader.GetAttribute("value"); 
							// On ferme alors le XmlTextReader 
							XmlReader.Close();

							// On retourne la valeur que l'on vient de trouver
							return Value;
						}
					}
				}
			}
			catch (XmlException Ex)
			{
				MessageBox.Show("Erreur inattendue.\n" + Ex.Message, "Erreur", MessageBoxButtons.OK, MessageBoxIcon.Exclamation, MessageBoxDefaultButton.Button1);
			}
			finally
			{
				// Fermeture de XmlReader qui a charg le fichier de configuration
				if ( XmlReader != null )
				{
					XmlReader.Close();
				}
			}

			return Value;
		}

		/// <summary>
		/// Insre, dans le fichier XML, la valeur de noeud demand.
		/// </summary>
		/// <param name="ElementName">Noeud dont on veut modifier la valeur</param>
		/// <param name="sValue">Nouvelle valeur que l'on veut affecter au noeud</param>
		/// <returns>Une chane de caractre reprsentant la valeur de noeud demnd.</returns>
		public void SetXmlValue(string ElementName, string sValue)
		{
			XmlTextReader XmlReader = null; 
			XmlTextWriter XmlWritter = new XmlTextWriter(CONFIG_FILE, System.Text.Encoding.UTF8);
			XmlWritter.Formatting = Formatting.Indented;
				
			try 
			{
				// Lecture du fichier de configuation
				XmlReader = ReadConfig();
								
				// Tant que l'on peut lire
				while ( XmlReader.Read() )
				{
					// On rcupre le type de noeud actuel
					XmlNodeType NodeType = XmlReader.NodeType;		
					
					// Si c'est un lment
					if( NodeType == XmlNodeType.Element )
					{
						// et qu'il vaut "add" et que la valeur de "key" est gale ) celle passe en paramtre
						if (XmlReader.Name.Equals("add") && XmlReader.GetAttribute("key").Equals(ElementName))
						{
							// On crit dans le fichier XML
							XmlWritter.WriteAttributeString(ElementName, sValue);

							// On ferme alors le XmlTextReader et XmlTextWriter
							XmlReader.Close();
							XmlWritter.Close();
						}
					}
				}
			}
			catch (XmlException Ex)
			{
				MessageBox.Show("Erreur inattendue.\n" + Ex.Message, "Erreur", MessageBoxButtons.OK, MessageBoxIcon.Exclamation, MessageBoxDefaultButton.Button1);
			}
			finally
			{
				// Fermeture de XmlReader qui a charg le fichier de configuration
				if ( XmlReader != null )
				{
					XmlReader.Close();
				}
				// Fermeture du XmlWritter
				if ( XmlWritter != null )
				{
					XmlWritter.Close();
				}
			}
		}
	}
}
